@@ -19,7 +19,7 @@ __date__ = "Jul 16, 2020"
 
 
 import copy
-from typing import Callable, Iterable, List
+from typing import Callable, Iterable, List, Tuple, Any
 
 import numpy as np
 import h5py
@@ -197,6 +197,12 @@ class FlattenedStorage(HasHDF):
 
     __version__ = "0.2.0"
     __hdf_version__ = "0.3.0"
+    _default_fill_values = {
+        np.dtype("int32"): -1,
+        np.dtype("int64"): -1,
+        np.dtype("float32"): np.nan,
+        np.dtype("float64"): np.nan,
+    }
 
     def __init__(self, num_chunks=1, num_elements=1, **kwargs):
         """
@@ -243,8 +249,10 @@ class FlattenedStorage(HasHDF):
         self._per_element_arrays = {}
 
         self._per_chunk_arrays = {
-            "start_index": np.empty(self._num_chunks_alloc, dtype=np.int32),
-            "length": np.empty(self._num_chunks_alloc, dtype=np.int32),
+            "start_index": np.full(
+                self._num_chunks_alloc, dtype=np.int32, fill_value=0
+            ),
+            "length": np.full(self._num_chunks_alloc, dtype=np.int32, fill_value=0),
             "identifier": np.empty(self._num_chunks_alloc, dtype=np.dtype("U20")),
         }
 
@@ -395,14 +403,8 @@ class FlattenedStorage(HasHDF):
         else:
             store[name] = np.full(shape=shape, fill_value=fill, dtype=dtype)
 
-        _default_fill_values = {
-            np.dtype("int32"): -1,
-            np.dtype("int64"): -1,
-            np.dtype("float32"): np.nan,
-            np.dtype("float64"): np.nan,
-        }
-        if fill is None and store[name].dtype in _default_fill_values:
-            fill = _default_fill_values[store[name].dtype]
+        if fill is None and store[name].dtype in self._default_fill_values:
+            fill = self._default_fill_values[store[name].dtype]
         if fill is not None:
             self._fill_values[name] = fill
 
@@ -796,6 +798,69 @@ class FlattenedStorage(HasHDF):
         self.current_element_index = i
         # return last_chunk_index, last_element_index
 
+    def extend(self, other: "FlattenedStorage"):
+        self._check_compatible_fill_values(other=other)
+
+        combined_num_chunks = self.num_chunks + other.num_chunks
+        combined_num_elements = self.num_elements + other.num_elements
+        if combined_num_chunks > self._num_chunks_alloc:
+            self._resize_chunks(combined_num_chunks)
+        if combined_num_elements > self._num_elements_alloc:
+            self._resize_elements(combined_num_elements)
+
+        for k, a in other._per_chunk_arrays.items():
+            # add start_index of last chunk to start_index of other for correct mapping
+            if (
+                k == "start_index" and len(self) > 0
+            ):  # Check if len > 0 to ensure that no random values are accessed for length and start_index after empty init
+                last = self.num_chunks - 1
+                len_last = self._per_chunk_arrays["length"][last]
+                a = (
+                    a + self._per_chunk_arrays[k][last] + len_last
+                )  # no += to prevent inplace mutation
+            if k not in self._per_chunk_arrays.keys():
+                dtype, fill = get_dtype_and_fill(storage=other, name=k)
+                self.add_array(
+                    name=k, dtype=dtype, shape=a.shape[1:], fill=fill, per="chunk"
+                )
+            self._per_chunk_arrays[k][self.num_chunks : combined_num_chunks] = a[
+                0 : other.num_chunks
+            ]
+
+        for k, a in other._per_element_arrays.items():
+            if k not in self._per_element_arrays.keys():
+                dtype, fill = get_dtype_and_fill(storage=other, name=k)
+                self.add_array(
+                    name=k, shape=a.shape[1:], dtype=dtype, fill=fill, per="element"
+                )
+            self._per_element_arrays[k][self.num_elements : combined_num_elements] = a[
+                0 : other.num_elements
+            ]
+        self.num_elements = combined_num_elements
+        self.num_chunks = combined_num_chunks
+        self.current_chunk_index = self.num_chunks
+        self.current_element_index = self.num_elements
+
+    def _check_compatible_fill_values(self, other: "FlattenedStorage"):
+        """
+        Check if fill values of 2 FlattenedStorages match to prevent errors due to wrong fill values,
+        f.e. after extending to the storage.
+
+        Args:
+            other (FlattenedStorage): Another FlattenedStorage instance
+
+        Raises:
+            ValueError: Raises when the storages have different fill values for a key
+        """
+        for k in set(self._fill_values).intersection(other._fill_values):
+            if np.isnan(self._fill_values[k]) and np.isnan(other._fill_values[k]):
+                continue
+            else:
+                if self._fill_values[k] != other._fill_values[k]:
+                    raise ValueError(
+                        "Fill values for arrays in storages don't match, can't perform requested operation"
+                    )
+
     def _get_hdf_group_name(self):
         return "flat_storage"
 
@@ -895,3 +960,20 @@ class FlattenedStorage(HasHDF):
 
         if version >= "0.3.0":
             self._fill_values = hdf["_fill_values"]
+
+
+def get_dtype_and_fill(storage: FlattenedStorage, name: str) -> Tuple[np.generic, Any]:
+    fill = None
+    if name in storage._fill_values.keys():
+        fill = storage._fill_values[name]
+        dtype = type(fill)
+    else:
+        a = storage.get_array(name)
+        dtype = a.dtype
+        try:
+            fill = FlattenedStorage._default_fill_values[dtype]
+        except KeyError:
+            raise ValueError(
+                f"Could not determine a default fill value for array {name}"
+            )
+    return dtype, fill
